@@ -1053,7 +1053,7 @@ lnt_rename_docx <- function(tbl, encoding, simulate, verbose) {
 #'
 #' Check for highly similar articles by comparing all articles published on the
 #' same date. This function implements two measures to test if articles are
-#' almost identical. The function \link[quanteda]{textstat_simil}, which
+#' almost identical. The function \link[quanteda.textstats]{textstat_simil}, which
 #' compares the word similarity of two given texts; and a relative modification
 #' of the generalized Levenshtein (edit) distance implementation in
 #' \link[stringdist]{stringdist}. The relative distance is calculated by
@@ -1101,7 +1101,8 @@ lnt_rename_docx <- function(tbl, encoding, simulate, verbose) {
 #' @author Johannes B. Gruber
 #' @export
 #' @importFrom stringdist stringdist
-#' @importFrom quanteda dfm docnames textstat_simil
+#' @importFrom quanteda dfm docnames
+#' @importFrom quanteda.textstats textstat_simil
 #' @importFrom utils combn
 #' @examples
 #' \dontrun{
@@ -1183,7 +1184,7 @@ lnt_similarity <- function(texts,
     verbose = FALSE
   )
   if (verbose) {
-    message("\t...quanteda dfm construced for similarity comparison [",
+    message("\t...quanteda dfm constructed for similarity comparison [",
       format(
         (Sys.time() - start_time),
         digits = 2, nsmall = 2
@@ -1195,7 +1196,7 @@ lnt_similarity <- function(texts,
   duplicates.df <- lapply(dates.d, function(x) {
     if (sum(x == na.omit(dates)) > 1) {
       text_dfm_day <- quanteda::dfm_subset(text_dfm, subset = (dates == x))
-      sim <- stats::as.dist(quanteda::textstat_simil(
+      sim <- stats::as.dist(textstat_simil(
         text_dfm_day,
         selection = NULL,
         method = "cosine",
@@ -1534,7 +1535,7 @@ lnt_lookup.character <- function(x,
                                  word_boundaries = c("both", "before", "after"),
                                  cores = NULL,
                                  verbose = TRUE) {
-  
+
   if (!is.null(word_boundaries) | isFALSE(word_boundaries)) {
     if (word_boundaries[1] == "both" | isTRUE(word_boundaries)) {
       pattern <- paste0(
@@ -1698,7 +1699,7 @@ lnt_diff <- function(x,
 #'
 #'   * tidytext ... passed on to [tidytext::unnest_tokens()].
 #'
-#'   * lnt2SQLite ... passed on to [RSQLite::dbWriteTable()].
+#'   * lnt2SQLite ... passed on to [`RSQLite::dbWriteTable-method()`][`RSQLite::dbWriteTable,SQLiteConnection,character,character-method`].
 #'
 #' @examples
 #' LNToutput <- lnt_read(lnt_sample(copy = FALSE))
@@ -1708,7 +1709,7 @@ lnt_diff <- function(x,
 #' docs <- lnt_convert(LNToutput, to = "rDNA")
 #'
 #' corpus <- lnt_convert(LNToutput, to = "quanteda")
-#' 
+#'
 #' \dontrun{
 #'
 #' tCorpus <- lnt_convert(LNToutput, to = "corpustools")
