@@ -74,6 +74,7 @@ test_that("Convert LNToutput to quanteda", {
 # saveRDS(corpus, "../files/quanteda_1.5.RDS")
 
 test_that("Convert LNToutput to corpustools", {
+  skip_if_not_installed("corpustools")
   expect_equal({
     cptools <- lnt_convert(x = readRDS("../files/LNToutput.RDS"),
                            to = "corpustools", what = "Articles")
@@ -99,6 +100,7 @@ test_that("Convert LNToutput to corpustools", {
 # }, "../files/corpustools.RDS")
 
 test_that("Convert LNToutput to tidytext", {
+  skip_if_not_installed("tidytext")
   expect_equivalent({
     lnt_convert(x = readRDS("../files/LNToutput.RDS"),
                            to = "tidytext", what = "Articles")
@@ -114,6 +116,7 @@ test_that("Convert LNToutput to tidytext", {
 #                     to = "tidytext", what = "Articles"), "../files/tidytext.RDS")
 
 test_that("Convert LNToutput to tm", {
+  skip_if_not_installed("tm")
   expect_equal({
     lnt_convert(x = readRDS("../files/LNToutput.RDS"),
                 to = "tm", what = "Articles")
@@ -144,6 +147,7 @@ test_that("Convert LNToutput to tm", {
 #                     to = "tm", what = "Articles"), "../files/tm.RDS")
 
 test_that("Convert LNToutput to SQLite", {
+  skip_if_not_installed("RSQLite")
   skip_on_cran()
   expect_equal({
     tempf <- paste0(tempdir(), "/LNT.sqlite")
